@@ -18,14 +18,14 @@
 
 import os, playlist, traceback
 
-from format          import monkeysaudio, asf, flac, mp3, mp4, mpc, ogg, wavpack
+from format          import monkeysaudio, asf, flac, mp3, mp4, mpc, ogg, wav, wavpack
 from os.path         import splitext
 from tools.log       import logger
 from track.fileTrack import FileTrack
 
 
 # Supported formats with associated modules
-mFormats = {'.ac3': monkeysaudio, '.ape': monkeysaudio, '.flac': flac, '.m4a': mp4, '.mp2': mp3, '.mp3': mp3, '.mp4': mp4, '.mpc': mpc,'.oga': ogg, '.ogg': ogg, '.wma': asf, '.wv': wavpack}
+mFormats = {'.ac3': monkeysaudio, '.ape': monkeysaudio, '.flac': flac, '.m4a': mp4, '.mp2': mp3, '.mp3': mp3, '.mp4': mp4, '.mpc': mpc,'.oga': ogg, '.ogg': ogg, '.wav': wav, '.wma': asf, '.wv': wavpack}
 
 
 def isSupported(file):
