@@ -329,12 +329,21 @@ class AudioCD(modules.ThreadedModule):
         """ Show a popup menu """
         popup = gtk.Menu()
 
-        # Play selection
+        # Play
         play = gtk.ImageMenuItem(gtk.STOCK_MEDIA_PLAY)
         play.set_sensitive(tree.getNbChildren((0,)) != 0)
         play.connect('activate', lambda widget: self.playPaths(tree, None, True))
         popup.append(play)
 
+        # Add
+        add = gtk.ImageMenuItem(gtk.STOCK_ADD)
+        add.set_sensitive(tree.getNbChildren((0,)) != 0)
+        add.connect('activate', lambda widget: self.playPaths(tree, None, False))
+        popup.append(add)
+
+        # Separator
+        popup.append(gtk.SeparatorMenuItem())
+
         # Refresh the view
         refresh = gtk.ImageMenuItem(gtk.STOCK_REFRESH)
         refresh.connect('activate', lambda widget: self.reloadDisc())
@@ -374,7 +383,7 @@ class AudioCD(modules.ThreadedModule):
     def configure(self, parent):
         """ Show the configuration window """
         if self.cfgWin is None:
-            self.cfgWin = gui.window.Window('AudioCD.glade', 'vbox1', __name__, MOD_L10N, 335, 270)
+            self.cfgWin = gui.window.Window('AudioCD.ui', 'vbox1', __name__, MOD_L10N, 335, 270)
             self.cfgWin.getWidget('btn-ok').connect('clicked', self.onBtnOk)
             self.cfgWin.getWidget('btn-help').connect('clicked', self.onBtnHelp)
             self.cfgWin.getWidget('chk-useCDDB').connect('toggled', self.onUseCDDBToggled)
