@@ -16,7 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 
-import gtk, modules
+import gtk, modules, tools
 
 from tools   import consts, prefs, sec2str
 from gettext import gettext as _
@@ -57,14 +57,18 @@ class CtrlPanel(modules.Module):
 
         # Widgets
         wTree             = prefs.getWidgetsTree()
-        self.btnStop      = wTree.get_widget('btn-stop')
-        self.btnPlay      = wTree.get_widget('btn-play')
-        self.btnNext      = wTree.get_widget('btn-next')
-        self.btnPrev      = wTree.get_widget('btn-previous')
-        self.sclSeek      = wTree.get_widget('scl-position')
-        self.btnVolume    = wTree.get_widget('btn-volume')
-        self.lblElapsed   = wTree.get_widget('lbl-elapsedTime')
-        self.lblRemaining = wTree.get_widget('lbl-remainingTime')
+        self.btnStop      = wTree.get_object('btn-stop')
+        self.btnPlay      = wTree.get_object('btn-play')
+        self.btnNext      = wTree.get_object('btn-next')
+        self.btnPrev      = wTree.get_object('btn-previous')
+        self.sclSeek      = wTree.get_object('scl-position')
+        self.btnVolume    = wTree.get_object('btn-volume')
+        self.lblElapsed   = wTree.get_object('lbl-elapsedTime')
+        self.lblRemaining = wTree.get_object('lbl-remainingTime')
+
+        # Don't show the volume button when using playbin2 and pulseaudio together (#511589)
+        if not tools.isPulseAudioRunning() or prefs.getCmdLine()[0].playbin or prefs.getCmdLine()[0].volume_button:
+            self.btnVolume.show()
 
         # Restore the volume
         volume = prefs.get(__name__, 'volume', PREFS_DEFAULT_VOLUME)
@@ -79,6 +83,8 @@ class CtrlPanel(modules.Module):
         self.sclSeek.connect('change-value', self.onSeekChangingValue)
         self.sclSeek.connect('value-changed', self.onSeekValueChanged)
         self.btnVolume.connect('value-changed', self.onVolumeValueChanged)
+        self.sclSeek.connect('button-press-event', self.onSeekButtonPressed)
+        self.sclSeek.connect('button-release-event', self.onSeekButtonReleased)
 
 
     def onAppQuit(self):
@@ -179,6 +185,24 @@ class CtrlPanel(modules.Module):
         self.lblRemaining.set_label(sec2str(self.currTrackLength - value))
 
 
+    def onSeekButtonPressed(self, range, event):
+        """ Mouse button has been pressed over the seek slider """
+        # Make left clicks act the same as middle clicks
+        if event.button == 1:
+            event.button = 2
+            range.emit('button-press-event', event)
+            return True
+
+
+    def onSeekButtonReleased(self, range, event):
+        """ Mouse button has been released over the seek slider """
+        # Make left clicks act the same as middle clicks
+        if event.button == 1:
+            event.button = 2
+            range.emit('button-release-event', event)
+            return True
+
+
     def onVolumeValueChanged(self, button, value):
         """ The user has moved the volume slider """
         modules.postMsg(consts.MSG_CMD_SET_VOLUME, {'value': value})
