@@ -130,11 +130,6 @@ class FileExplorer(modules.Module):
                    }
 
 
-    def sortKey(self, row):
-        """ Key function used to compare two rows of the tree """
-        return row[ROW_NAME].lower()
-
-
     def setShowHiddenFiles(self, showHiddenFiles):
         """ Show/hide hidden files """
         if showHiddenFiles != self.showHiddenFiles:
@@ -188,6 +183,18 @@ class FileExplorer(modules.Module):
             self.tree.setItem(row, ROW_NAME, name[:index-2])
 
 
+    def __cmpRowsOnFilename(self, r1, r2):
+        """
+            Compare two filenames:
+              - First the lower case version (we want 'bar' to be before 'Foo')
+              - Then, if an equality occurs, the normal version (we want 'Foo' and 'foo' to be different folders)
+        """
+        result = cmp(r1[ROW_NAME].lower(), r2[ROW_NAME].lower())
+
+        if result == 0: return cmp(r1[ROW_NAME], r2[ROW_NAME])
+        else:           return result
+
+
     def getDirContents(self, directory):
         """ Return a tuple of sorted rows (directories, playlists, mediaFiles) for the given directory """
         playlists   = []
@@ -203,9 +210,10 @@ class FileExplorer(modules.Module):
                 elif playlist.isSupported(file):
                     playlists.append((icons.mediaFileMenuIcon(), tools.htmlEscape(unicode(file, errors='replace')), TYPE_FILE, path))
 
-        playlists.sort(key=self.sortKey)
-        mediaFiles.sort(key=self.sortKey)
-        directories.sort(key=self.sortKey)
+        # Individually sort each type of file by name
+        playlists.sort(cmp=self.__cmpRowsOnFilename)
+        mediaFiles.sort(cmp=self.__cmpRowsOnFilename)
+        directories.sort(cmp=self.__cmpRowsOnFilename)
 
         return (directories, playlists, mediaFiles)
 
@@ -274,8 +282,7 @@ class FileExplorer(modules.Module):
             if rowPath is None:
                 break
 
-            file      = disk[diskIndex]
-            cmpResult = cmp(self.sortKey(self.tree.getRow(rowPath)), self.sortKey(file))
+            cmpResult = self.__cmpRowsOnFilename(self.tree.getRow(rowPath), disk[diskIndex])
 
             if cmpResult < 0:
                 # We can't remove the only child left, to prevent the node from being closed automatically
@@ -286,7 +293,7 @@ class FileExplorer(modules.Module):
                 self.tree.removeRow(rowPath)
             else:
                 if cmpResult > 0:
-                    self.tree.insertRowBefore(file, treePath, rowPath)
+                    self.tree.insertRowBefore(disk[diskIndex], treePath, rowPath)
                 diskIndex  += 1
                 childIndex += 1
 
@@ -334,13 +341,20 @@ class FileExplorer(modules.Module):
         """ Show a popup menu """
         popup = gtk.Menu()
 
-        # Play selection
+        # Play
         play = gtk.ImageMenuItem(gtk.STOCK_MEDIA_PLAY)
         popup.append(play)
 
         if path is None: play.set_sensitive(False)
         else:            play.connect('activate', lambda widget: self.play(True))
 
+        # Add
+        add = gtk.ImageMenuItem(gtk.STOCK_ADD)
+        popup.append(add)
+
+        if path is None: add.set_sensitive(False)
+        else:            add.connect('activate', lambda widget: self.play(False))
+
         popup.append(gtk.SeparatorMenuItem())
 
         # Collapse all nodes
@@ -466,7 +480,7 @@ class FileExplorer(modules.Module):
         if self.cfgWin is None:
             from gui import extListview, window
 
-            self.cfgWin = window.Window('FileExplorer.glade', 'vbox1', __name__, MOD_L10N, 370, 400)
+            self.cfgWin = window.Window('FileExplorer.ui', 'vbox1', __name__, MOD_L10N, 370, 400)
             # Create the list of folders
             txtRdr  = gtk.CellRendererText()
             pixRdr  = gtk.CellRendererPixbuf()
@@ -497,7 +511,7 @@ class FileExplorer(modules.Module):
 
     def populateFolderList(self):
         """ Populate the list of known folders """
-        self.cfgList.replaceContent([(name, icons.dirBtnIcon(), '<b>%s</b>\n<small>%s</small>' % (tools.htmlEscape(name), tools.htmlEscape(path)))
+        self.cfgList.replaceContent([(name, icons.dirToolbarIcon(), '<b>%s</b>\n<small>%s</small>' % (tools.htmlEscape(name), tools.htmlEscape(path)))
                                      for name, path in sorted(self.folders.iteritems())])
 
 
