@@ -62,8 +62,9 @@ MOD_L10N = MOD_INFO[modules.MODINFO_L10N]
     TYPE_TRACK,             # Single track
     TYPE_HEADER,            # Alphabetical header
     TYPE_FAVORITES_BANNER,  # Favorites banner (when showing only favorites)
+    TYPE_GENRE_BANNER,      # Shown when filtering by genre
     TYPE_NONE               # Used for fake children
-) = range(6)
+) = range(7)
 
 
 # The format of a row in the treeview
@@ -78,13 +79,14 @@ MOD_L10N = MOD_INFO[modules.MODINFO_L10N]
 
 
 # Constants
-VERSION                           = 3                                      # Used to check compatibility
+VERSION                           = 4                                      # Used to check compatibility
 ROOT_PATH                         = os.path.join(consts.dirCfg, 'Library') # Path where libraries are stored
 FAKE_CHILD                        = (None, None, '', TYPE_NONE, '', None)  # We use a lazy tree
 PREFS_DEFAULT_PREFIXES            = {'the ': None}                         # Prefixes are put at the end of artists' names
 PREFS_DEFAULT_LIBRARIES           = {}                                     # No libraries at first
 PREFS_DEFAULT_TREE_STATE          = {}                                     # No state at first
-PREFS_DEFAULT_SHOW_ONLY_FAVORITES = False
+PREFS_DEFAULT_GENRE_FILTERS       = {}                                     # Unfiltered libraries by default
+PREFS_DEFAULT_SHOW_ONLY_FAVORITES = False                                  # Show all files by default
 
 
 class Library(modules.Module):
@@ -148,7 +150,7 @@ class Library(modules.Module):
 
     def __drawCell(self, column, cell, model, iter):
         """ Use a different background color for alphabetical headers """
-        if model.get_value(iter, ROW_TYPE) == TYPE_HEADER: cell.set_property('cell-background-gdk', self.tree.style.bg[gtk.STATE_PRELIGHT])
+        if model.get_value(iter, ROW_TYPE) == TYPE_HEADER: cell.set_property('cell-background-gdk', self.tree.style.base[gtk.STATE_PRELIGHT])
         else:                                              cell.set_property('cell-background',     None)
 
 
@@ -252,16 +254,22 @@ class Library(modules.Module):
         # Create the database
         for track in mediaFiles:
             album = track.getExtendedAlbum()
+            genre = track.getGenre().lower()
 
             if track.hasAlbumArtist(): artist = track.getAlbumArtist()
             else:                      artist = track.getArtist()
 
             if artist in db:
                 allAlbums = db[artist]
-                if album in allAlbums: allAlbums[album].append(track)
-                else:                  allAlbums[album] = [track]
+
+                try:
+                    albumNfo = allAlbums[album]
+                    albumNfo[0][genre] = None
+                    albumNfo[1].append(track)
+                except:
+                    allAlbums[album] = ({genre: None}, [track])
             else:
-                db[artist] = {album: [track]}
+                db[artist] = {album: ({genre: None}, [track])}
 
         progress.pulse()
         yield True
@@ -295,28 +303,43 @@ class Library(modules.Module):
         overallNbArtists = len(db)
 
         # The 'artists' file contains all known artists with their index, the 'files' file contains the file structure of the root path
-        allArtists = sorted([(artist, str(indexArtist), len(db[artist])) for indexArtist, artist in enumerate(db)], key = lambda a: a[0].lower())
+        allArtists = sorted([(artist, str(indexArtist), len(albums)) for indexArtist, (artist, albums) in enumerate(db.iteritems())], key = lambda a: a[0].lower())
         pickleSave(os.path.join(libPath, 'files'),   newLibrary)
         pickleSave(os.path.join(libPath, 'artists'), allArtists)
 
+        # Keep track of genre through nested dictionaries genres -> artists -> albums
+        allGenres = {}
+
         for (artist, indexArtist, nbAlbums) in allArtists:
             artistPath       = os.path.join(libPath, indexArtist)
             overallNbAlbums += nbAlbums
             os.mkdir(artistPath)
 
             albums = []
-            for index, (name, tracks) in enumerate(db[artist].iteritems()):
+            for index, (name, (albumGenres, tracks)) in enumerate(db[artist].iteritems()):
                 length           = sum([track.getLength() for track in tracks])
                 overallNbTracks += len(tracks)
 
                 albums.append((name, str(index), len(tracks), length))
                 pickleSave(os.path.join(artistPath, str(index)), sorted(tracks, key = lambda track: track.getNumber()))
 
-            albums.sort(cmp = lambda a1, a2: cmp(db[artist][a1[0]][0], db[artist][a2[0]][0]))
+                # Update the dictionary with the genres
+                for genre in albumGenres:
+                    try:
+                        allGenres[genre][artist][name] = None
+                    except:
+                        try:
+                            allGenres[genre][artist] = {name: None}
+                        except:
+                            allGenres[genre] = {artist: {name: None}}
+
+            albums.sort()
             pickleSave(os.path.join(artistPath, 'albums'), albums)
             progress.pulse()
             yield True
 
+        pickleSave(os.path.join(libPath, 'genres'), allGenres)
+
         self.libraries[libName] = (path, overallNbArtists, overallNbAlbums, overallNbTracks)
         self.fillLibraryList()
         if creation:
@@ -329,7 +352,7 @@ class Library(modules.Module):
             if artist in db:
                 newFavorites[artist] = {}
                 for album in albums:
-                    if album in db[artist]:
+                    if album in db[artist][1]:
                         newFavorites[artist][album] = None
 
         self.saveFavorites(libName, newFavorites)
@@ -437,7 +460,7 @@ class Library(modules.Module):
                     self.addToFavorites(artist, album)
 
         # If some favorites were removed, we may have to reload the tree
-        if self.showOnlyFavorites and removed:
+        if self.showOnlyFavs and removed:
             self.saveTreeState()
             self.loadArtists(self.tree, self.currLib)
             self.restoreTreeState()
@@ -446,8 +469,17 @@ class Library(modules.Module):
     def switchFavoritesView(self, tree):
         """ Show all/favorites """
         self.saveTreeState()
-        self.showOnlyFavorites = not self.showOnlyFavorites
-        prefs.set(__name__, 'show-only-favorites', self.showOnlyFavorites)
+        self.showOnlyFavs = not self.showOnlyFavs
+        prefs.set(__name__, 'show-only-favorites', self.showOnlyFavs)
+        self.loadArtists(self.tree, self.currLib)
+        self.restoreTreeState()
+
+
+    def filterByGenre(self, genre):
+        """ Filter the library and keep only albums of the given genre """
+        self.saveTreeState()
+        self.currGenre = genre
+        self.saveGenreFilter(self.currLib, genre)
         self.loadArtists(self.tree, self.currLib)
         self.restoreTreeState()
 
@@ -463,6 +495,13 @@ class Library(modules.Module):
         if path is None: play.set_sensitive(False)
         else:            play.connect('activate', lambda widget: self.playPaths(tree, None, True))
 
+        # Add
+        add = gtk.ImageMenuItem(gtk.STOCK_ADD)
+        popup.append(add)
+
+        if path is None: add.set_sensitive(False)
+        else:            add.connect('activate', lambda widget: self.playPaths(tree, None, False))
+
         # Separator
         popup.append(gtk.SeparatorMenuItem())
 
@@ -493,13 +532,40 @@ class Library(modules.Module):
 
         # Show only favorites
         showFavorites = gtk.CheckMenuItem(_('Show Only Favorites'))
-        showFavorites.set_active(self.showOnlyFavorites)
+        showFavorites.set_active(self.showOnlyFavs)
         showFavorites.connect('toggled', lambda widget: self.switchFavoritesView(tree))
         popup.append(showFavorites)
 
         # Separator
         popup.append(gtk.SeparatorMenuItem())
 
+        # Filter by genre
+        genresMenu  = gtk.Menu()
+        filterGenre = gtk.MenuItem(_("Filter by Genre"));
+
+        filterGenre.set_submenu(genresMenu)
+        popup.append(filterGenre)
+
+        # Need to keep the mapping widget -> genre to handle activate events
+        self.genreItemToName = {}
+
+        for genre in sorted(self.allGenres):
+            genreItem = gtk.CheckMenuItem(genre.capitalize())
+            genreItem.set_active(genre == self.currGenre)
+            self.genreItemToName[genreItem] = genre
+            genreItem.connect('activate', lambda widget: self.filterByGenre(self.genreItemToName[widget]))
+            genresMenu.append(genreItem)
+
+        genresMenu.append(gtk.SeparatorMenuItem())
+
+        genreItem = gtk.CheckMenuItem(_('Unfiltered'))
+        genreItem.set_active(self.currGenre == None)
+        genreItem.connect('activate', lambda widget: self.filterByGenre(None))
+        genresMenu.append(genreItem)
+
+        # Separator
+        popup.append(gtk.SeparatorMenuItem())
+
         # Collapse all nodes
         collapse = gtk.ImageMenuItem(_('Collapse all'))
         collapse.set_image(gtk.image_new_from_stock(gtk.STOCK_CLEAR, gtk.ICON_SIZE_MENU))
@@ -555,13 +621,21 @@ class Library(modules.Module):
             tree.replaceContent([(icons.errorMenuIcon(), None, error, TYPE_NONE, None, None)])
             return
 
-        rows       = []
-        icon       = icons.dirMenuIcon()
-        prevChar   = ''
-        allArtists = pickleLoad(os.path.join(libPath, 'artists'))
+        rows           = []
+        icon           = icons.dirMenuIcon()
+        prevChar       = ''
+        allArtists     = pickleLoad(os.path.join(libPath, 'artists'))
+        self.allGenres = pickleLoad(os.path.join(libPath, 'genres'))
 
-        # Filter artists if needed
-        if self.showOnlyFavorites:
+        # Filter artists by genre if needed
+        if self.currGenre is not None:
+            allArtists = [artist for artist in allArtists if artist[ART_NAME] in self.allGenres[self.currGenre]]
+            rows.append((icons.infoMenuIcon(), None, '<b>%s</b>' % self.currGenre.capitalize(), TYPE_GENRE_BANNER, None, None))
+        else:
+            rows.append((icons.infoMenuIcon(), None, '<b>%s</b>' % _('All genres'), TYPE_GENRE_BANNER, None, None))
+
+        # Filter artists by favorites if needed
+        if self.showOnlyFavs:
             allArtists = [artist for artist in allArtists if self.isArtistInFavorites(artist[ART_NAME])]
             rows.append((icons.starMenuIcon(), None, '<b>%s</b>' % _('My Favorites'), TYPE_FAVORITES_BANNER, None, None))
 
@@ -592,9 +666,13 @@ class Library(modules.Module):
         allAlbums = pickleLoad(os.path.join(tree.getItem(node, ROW_FULLPATH), 'albums'))
 
         # Filter albums if only favorites should be shown
-        if self.showOnlyFavorites:
+        if self.showOnlyFavs:
             allAlbums = [album for album in allAlbums if self.isAlbumInFavorites(artist, album[ALB_NAME])]
 
+        # Filter artists by genre if needed
+        if self.currGenre is not None:
+            allAlbums = [album for album in allAlbums if album[ALB_NAME] in self.allGenres[self.currGenre][artist]]
+
         # The icon depends on whether the album is in the favorites
         for album in allAlbums:
             if self.isAlbumInFavorites(artist, album[ALB_NAME]): icon = icons.starDirMenuIcon()
@@ -625,23 +703,22 @@ class Library(modules.Module):
 
     def saveTreeState(self):
         """ Save the current tree state """
-        if self.showOnlyFavorites: self.treeStates[self.currLib + ' favorites'] = self.tree.saveState(ROW_NAME)
-        else:                      self.treeStates[self.currLib]                = self.tree.saveState(ROW_NAME)
+        state = self.tree.saveState(ROW_NAME)
+
+        try:    self.treeStates[self.currLib][(self.currGenre, self.showOnlyFavs)] = state
+        except: self.treeStates[self.currLib] = {(self.currGenre, self.showOnlyFavs): state}
 
 
     def restoreTreeState(self):
         """ Restore the tree state """
-        if self.showOnlyFavorites: name = self.currLib + ' favorites'
-        else:                      name = self.currLib
-
-        if name in self.treeStates:
-            self.tree.restoreState(self.treeStates[name], ROW_NAME)
+        try:    self.tree.restoreState(self.treeStates[self.currLib][(self.currGenre, self.showOnlyFavs)], ROW_NAME)
+        except: pass
 
 
     def removeTreeStates(self, libName):
         """ Remove the tree states associated to the given library """
-        if libName in self.treeStates:                del self.treeStates[libName]
-        if libName + ' favorites' in self.treeStates: del self.treeStates[libName + ' favorites']
+        if libName in self.treeStates:
+            del self.treeStates[libName]
 
 
     def renameTreeStates(self, oldLibName, newLibName):
@@ -650,9 +727,22 @@ class Library(modules.Module):
             self.treeStates[newLibName] = self.treeStates[oldLibName]
             del self.treeStates[oldLibName]
 
-        if oldLibName + ' favorites' in self.treeStates:
-            self.treeStates[newLibName + ' favorites'] = self.treeStates[oldLibName + ' favorites']
-            del self.treeStates[oldLibName + ' favorites']
+
+    # --== Filtering by genre ==--
+
+    def loadGenreFilter(self, libName):
+        """ Load the last genre used to filter the given library """
+        savedGenreFilters = prefs.get(__name__, 'genre-filters', PREFS_DEFAULT_GENRE_FILTERS)
+
+        try:    return savedGenreFilters[libName]
+        except: return None
+
+
+    def saveGenreFilter(self, libName, genre):
+        """ Save the current genre used to filter the given library """
+        savedGenreFilters = prefs.get(__name__, 'genre-filters', PREFS_DEFAULT_GENRE_FILTERS)
+        savedGenreFilters[libName] = genre
+        prefs.set(__name__, 'genre-filters', savedGenreFilters)
 
 
     # --== Favorites ==--
@@ -757,13 +847,15 @@ class Library(modules.Module):
 
     def onModLoaded(self):
         """ This is the real initialization function, called when the module has been loaded """
-        self.tree              = None
-        self.currLib           = None
-        self.cfgWindow         = None
-        self.libraries         = prefs.get(__name__, 'libraries',  PREFS_DEFAULT_LIBRARIES)
-        self.favorites         = None
-        self.treeStates        = prefs.get(__name__, 'tree-state', PREFS_DEFAULT_TREE_STATE)
-        self.showOnlyFavorites = prefs.get(__name__, 'show-only-favorites', PREFS_DEFAULT_SHOW_ONLY_FAVORITES)
+        self.tree         = None
+        self.currLib      = None
+        self.allGenres    = {}
+        self.currGenre    = None
+        self.cfgWindow    = None
+        self.libraries    = prefs.get(__name__, 'libraries',  PREFS_DEFAULT_LIBRARIES)
+        self.favorites    = None
+        self.treeStates   = prefs.get(__name__, 'tree-states-2', PREFS_DEFAULT_TREE_STATE)
+        self.showOnlyFavs = prefs.get(__name__, 'show-only-favorites', PREFS_DEFAULT_SHOW_ONLY_FAVORITES)
         # Scroll window
         self.scrolled = gtk.ScrolledWindow()
         self.scrolled.set_shadow_type(gtk.SHADOW_IN)
@@ -778,7 +870,7 @@ class Library(modules.Module):
         if self.currLib is not None:
             self.saveTreeState()
             self.saveFavorites(self.currLib, self.favorites)
-            prefs.set(__name__, 'tree-state', self.treeStates)
+            prefs.set(__name__, 'tree-states-2', self.treeStates)
 
         prefs.set(__name__, 'libraries',  self.libraries)
         self.removeAllExplorers()
@@ -799,6 +891,7 @@ class Library(modules.Module):
             # Switch to the new library
             self.currLib   = expName
             self.favorites = self.loadFavorites(self.currLib)
+            self.currGenre = self.loadGenreFilter(self.currLib)
             self.loadArtists(self.tree, self.currLib)
             self.restoreTreeState()
 
@@ -811,7 +904,7 @@ class Library(modules.Module):
         if self.cfgWindow is None:
             from gui import extListview, window
 
-            self.cfgWindow = window.Window('Library.glade', 'vbox1', __name__, MOD_L10N, 370, 400)
+            self.cfgWindow = window.Window('Library.ui', 'vbox1', __name__, MOD_L10N, 370, 400)
             # Create the list of libraries
             txtRdr  = gtk.CellRendererText()
             pixRdr  = gtk.CellRendererPixbuf()
@@ -896,7 +989,7 @@ class Library(modules.Module):
     def fillLibraryList(self):
         """ Fill the list of libraries """
         if self.cfgWindow is not None:
-            rows = [(name, icons.dirBtnIcon(), '<b>%s</b>\n<small>%s - %u %s</small>' % (htmlEscape(name), htmlEscape(path), nbTracks, htmlEscape(_('tracks'))))
+            rows = [(name, icons.dirToolbarIcon(), '<b>%s</b>\n<small>%s - %u %s</small>' % (htmlEscape(name), htmlEscape(path), nbTracks, htmlEscape(_('tracks'))))
                     for name, (path, nbArtists, nbAlbums, nbTracks) in sorted(self.libraries.iteritems())]
             self.cfgList.replaceContent(rows)
 
