@@ -86,9 +86,9 @@ class StatusbarTitlebar(modules.Module):
 
     def onAppStarted(self):
         """ Real initialization function, called when this module has been loaded """
-        self.window  = prefs.getWidgetsTree().get_widget('win-main')
-        self.status1 = prefs.getWidgetsTree().get_widget('lbl-status1')
-        self.status2 = prefs.getWidgetsTree().get_widget('lbl-status2')
+        self.window  = prefs.getWidgetsTree().get_object('win-main')
+        self.status1 = prefs.getWidgetsTree().get_object('lbl-status1')
+        self.status2 = prefs.getWidgetsTree().get_object('lbl-status2')
 
         # Current player status
         self.paused    = False
