@@ -37,9 +37,10 @@ MOD_INFO = ('Tracklist', 'Tracklist', '', [], True, False, consts.MODCAT_NONE)
     ROW_BTR,   # Bit rate
     ROW_GNR,   # Genre
     ROW_DAT,   # Date
+    ROW_FIL,   # Filename
     ROW_PTH,   # Path to the file
-    ROW_TRK    # The Track object
-) = range(11)
+    ROW_TRK,   # The Track object
+) = range(12)
 
 # Create a unique ID for each column that the user can see
 (
@@ -52,7 +53,8 @@ MOD_INFO = ('Tracklist', 'Tracklist', '', [], True, False, consts.MODCAT_NONE)
     COL_LENGTH,
     COL_PATH,
     COL_BITRATE,
-) = range(9)
+    COL_FILENAME,
+) = range(10)
 
 PREFS_DEFAULT_REPEAT_STATUS      = False
 PREFS_DEFAULT_COLUMNS_VISIBILITY = {
@@ -64,6 +66,7 @@ PREFS_DEFAULT_COLUMNS_VISIBILITY = {
                                         COL_GENRE    : False,
                                         COL_LENGTH   : True,
                                         COL_BITRATE  : False,
+                                        COL_FILENAME : False,
                                         COL_PATH     : False,
                                    }
 
@@ -74,22 +77,24 @@ class Tracklist(modules.Module):
     def __init__(self):
         """ Constructor """
         handlers = {
-                        consts.MSG_CMD_NEXT:              self.jumpToNext,
-                        consts.MSG_EVT_PAUSED:            lambda: self.onPausedToggled(icons.pauseMenuIcon()),
-                        consts.MSG_EVT_STOPPED:           self.onStopped,
-                        consts.MSG_EVT_UNPAUSED:          lambda: self.onPausedToggled(icons.playMenuIcon()),
-                        consts.MSG_CMD_PREVIOUS:          self.jumpToPrevious,
-                        consts.MSG_EVT_NEED_BUFFER:       self.onBufferingNeeded,
-                        consts.MSG_EVT_APP_STARTED:       self.onAppStarted,
-                        consts.MSG_CMD_TOGGLE_PAUSE:      self.togglePause,
-                        consts.MSG_CMD_TRACKLIST_DEL:     self.remove,
-                        consts.MSG_CMD_TRACKLIST_ADD:     self.insert,
-                        consts.MSG_CMD_TRACKLIST_SET:     self.set,
-                        consts.MSG_CMD_TRACKLIST_CLR:     lambda: self.set(None, None),
-                        consts.MSG_EVT_TRACK_ENDED_OK:    lambda: self.onTrackEnded(False),
-                        consts.MSG_CMD_TRACKLIST_REPEAT:  self.setRepeat,
-                        consts.MSG_EVT_TRACK_ENDED_ERROR: lambda: self.onTrackEnded(True),
-                        consts.MSG_CMD_TRACKLIST_SHUFFLE: self.shuffleTracklist,
+                        consts.MSG_CMD_NEXT:                 self.jumpToNext,
+                        consts.MSG_EVT_PAUSED:               lambda: self.onPausedToggled(icons.pauseMenuIcon()),
+                        consts.MSG_EVT_STOPPED:              self.onStopped,
+                        consts.MSG_EVT_UNPAUSED:             lambda: self.onPausedToggled(icons.playMenuIcon()),
+                        consts.MSG_CMD_PREVIOUS:             self.jumpToPrevious,
+                        consts.MSG_EVT_NEED_BUFFER:          self.onBufferingNeeded,
+                        consts.MSG_EVT_APP_STARTED:          self.onAppStarted,
+                        consts.MSG_CMD_TOGGLE_PAUSE:         self.togglePause,
+                        consts.MSG_CMD_TRACKLIST_DEL:        self.remove,
+                        consts.MSG_CMD_TRACKLIST_ADD:        self.insert,
+                        consts.MSG_CMD_TRACKLIST_SET:        self.set,
+                        consts.MSG_CMD_TRACKLIST_CLR:        lambda: self.set(None, False, False),
+                        consts.MSG_CMD_TRACKLIST_PLAY:       self.onTracklistPlay,
+                        consts.MSG_EVT_TRACK_ENDED_OK:       lambda: self.onTrackEnded(False),
+                        consts.MSG_CMD_TRACKLIST_REPEAT:     self.setRepeat,
+                        consts.MSG_EVT_TRACK_ENDED_ERROR:    lambda: self.onTrackEnded(True),
+                        consts.MSG_CMD_TRACKLIST_SHUFFLE:    self.shuffleTracklist,
+                        consts.MSG_CMD_TRACKLIST_PLAY_PAUSE: self.onTracklistPlayPause,
                    }
 
         modules.Module.__init__(self, handlers)
@@ -150,7 +155,7 @@ class Tracklist(modules.Module):
             self.jumpTo(where)
 
 
-    def jumpTo(self, trackIdx, sendPlayMsg = True):
+    def jumpTo(self, trackIdx, sendPlayMsg = True, forced = True):
         """ Jump to the track located at the given index """
         if self.list.hasMark() and self.list.getItem(self.list.getMark(), ROW_ICO) != icons.errorMenuIcon():
             self.list.setItem(self.list.getMark(), ROW_ICO, icons.nullMenuIcon())
@@ -159,7 +164,7 @@ class Tracklist(modules.Module):
         self.list.setItem(trackIdx, ROW_ICO, icons.playMenuIcon())
 
         if sendPlayMsg:
-            modules.postMsg(consts.MSG_CMD_PLAY, {'uri': self.list.getItem(trackIdx, ROW_TRK).getURI()})
+            modules.postMsg(consts.MSG_CMD_PLAY, {'uri': self.list.getItem(trackIdx, ROW_TRK).getURI(), 'forced': forced})
 
         modules.postMsg(consts.MSG_EVT_NEW_TRACK,   {'track': self.list.getRow(trackIdx)[ROW_TRK]})
         modules.postMsg(consts.MSG_EVT_TRACK_MOVED, {'hasPrevious': self.__hasPreviousTrack(), 'hasNext': self.__hasNextTrack()})
@@ -167,8 +172,8 @@ class Tracklist(modules.Module):
 
     def insert(self, tracks, playNow, position=None):
         """ Insert some tracks in the tracklist, append them if position is None """
-        rows = [[icons.nullMenuIcon(), track.getNumber(), track.getTitle(), track.getArtist(), track.getExtendedAlbum(),
-                    track.getLength(), track.getBitrate(), track.getGenre(), track.getDate(), track.getURI(), track] for track in tracks]
+        rows = [[icons.nullMenuIcon(), track.getNumber(), track.getTitleOrFilename(), track.getArtist(), track.getExtendedAlbum(),
+                    track.getLength(), track.getBitrate(), track.getGenre(), track.getDate(), track.getFilename(), track.getURI(), track] for track in tracks]
 
         if len(rows) != 0:
             self.previousTracklist = [row[ROW_TRK] for row in self.list]
@@ -183,7 +188,7 @@ class Tracklist(modules.Module):
                 else:                    self.jumpTo(len(self.previousTracklist))
 
 
-    def set(self, tracks, playNow):
+    def set(self, tracks, playNow, keepCurrTrack = False):
         """ Replace the tracklist, clear it if tracks is None """
         self.playtime = 0
 
@@ -191,7 +196,25 @@ class Tracklist(modules.Module):
         # The insert() function would overwrite it otherwise
         previousTracklist = [row[ROW_TRK] for row in self.list]
 
-        if self.list.hasMark() and ((not playNow) or (tracks is None) or (len(tracks) == 0)):
+        # Should we stop playback?
+        sendStop        = False
+        keepTrackNewIdx = -1
+
+        # If we should keep the current track but it doesn't belong to the new playlist
+        if keepCurrTrack and self.list.hasMark():
+            sendStop  = True
+            currTrack = self.list.getRow(self.list.getMark())[ROW_TRK]
+
+            for idx, track in enumerate(tracks):
+                if track == currTrack:
+                    sendStop        = False
+                    keepTrackNewIdx = idx
+                    break
+        # Or if we shouldn't start playback now or the new playlist is empty
+        elif self.list.hasMark() and ((not playNow) or (tracks is None) or (len(tracks) == 0)):
+            sendStop = True
+
+        if sendStop:
             modules.postMsg(consts.MSG_CMD_STOP)
 
         self.list.clear()
@@ -201,6 +224,10 @@ class Tracklist(modules.Module):
 
         self.previousTracklist = previousTracklist
 
+        # Mark the current track if we kept the same one
+        if keepCurrTrack and keepTrackNewIdx != -1:
+            self.jumpTo(keepTrackNewIdx, False, False)
+
 
     def savePlaylist(self):
         """ Save the current tracklist to a playlist """
@@ -246,7 +273,7 @@ class Tracklist(modules.Module):
 
     def revertTracklist(self):
         """ Back to the previous tracklist """
-        self.set(self.previousTracklist, False)
+        self.set(self.previousTracklist, False, True)
         self.previousTracklist = None
 
 
@@ -350,10 +377,10 @@ class Tracklist(modules.Module):
         self.bufferedTrack     = None
         self.previousTracklist = None
         # Retrieve widgets
-        self.window     = wTree.get_widget('win-main')
-        self.btnClear   = wTree.get_widget('btn-tracklistClear')
-        self.btnRepeat  = wTree.get_widget('btn-tracklistRepeat')
-        self.btnShuffle = wTree.get_widget('btn-tracklistShuffle')
+        self.window     = wTree.get_object('win-main')
+        self.btnClear   = wTree.get_object('btn-tracklistClear')
+        self.btnRepeat  = wTree.get_object('btn-tracklistRepeat')
+        self.btnShuffle = wTree.get_object('btn-tracklistShuffle')
         self.btnClear.set_sensitive(False)
         self.btnShuffle.set_sensitive(False)
         # Create the list and its columns
@@ -376,6 +403,7 @@ class Tracklist(modules.Module):
                    (_('Bit Rate'), [(txtRRdr, TYPE_STRING)],                           (ROW_BTR, ROW_ART, ROW_ALB, ROW_NUM, ROW_TIT), False, visible[COL_BITRATE]),
                    (_('Genre'),    [(txtLRdr, TYPE_STRING)],                           (ROW_GNR, ROW_ART, ROW_ALB, ROW_NUM, ROW_TIT), False, visible[COL_GENRE]),
                    (_('Date'),     [(txtLRdr, TYPE_INT)],                              (ROW_DAT, ROW_ART, ROW_ALB, ROW_NUM, ROW_TIT), False, visible[COL_DATE]),
+                   (_('Filename'), [(txtLRdr, TYPE_STRING)],                           (ROW_FIL,),                                    False, visible[COL_FILENAME]),
                    (_('Path'),     [(txtLRdr, TYPE_STRING)],                           (ROW_PTH,),                                    False, visible[COL_PATH]),
                    (None,          [(None, TYPE_PYOBJECT)],                            (None,),                                       False, False))
 
@@ -383,7 +411,7 @@ class Tracklist(modules.Module):
         self.list.get_column(1).set_cell_data_func(txtLRdr, self.__fmtColumnColor)
         self.list.get_column(4).set_cell_data_func(txtRRdr, self.__fmtLengthColumn)
         self.list.enableDNDReordering()
-        wTree.get_widget('scrolled-tracklist').add(self.list)
+        wTree.get_object('scrolled-tracklist').add(self.list)
         # GTK handlers
         self.list.connect('extlistview-dnd', self.onDND)
         self.list.connect('key-press-event', self.onKeyboard)
@@ -397,8 +425,8 @@ class Tracklist(modules.Module):
         # Restore preferences
         self.btnRepeat.set_active(tools.prefs.get(__name__, 'repeat-status', PREFS_DEFAULT_REPEAT_STATUS))
         # Set icons
-        wTree.get_widget('img-repeat').set_from_icon_name('stock_repeat', gtk.ICON_SIZE_BUTTON)
-        wTree.get_widget('img-shuffle').set_from_icon_name('stock_shuffle', gtk.ICON_SIZE_BUTTON)
+        wTree.get_object('img-repeat').set_from_icon_name('stock_repeat', gtk.ICON_SIZE_BUTTON)
+        wTree.get_object('img-shuffle').set_from_icon_name('stock_shuffle', gtk.ICON_SIZE_BUTTON)
 
 
     def onTrackEnded(self, withError):
@@ -418,7 +446,7 @@ class Tracklist(modules.Module):
 
             if self.list.getItem(currIdx, ROW_ICO) != icons.errorMenuIcon():
                 track = self.list.getItem(currIdx, ROW_TRK).getURI()
-                self.jumpTo(currIdx, track != self.bufferedTrack)
+                self.jumpTo(currIdx, track != self.bufferedTrack, forced = False)
                 self.bufferedTrack = None
                 return
 
@@ -449,6 +477,20 @@ class Tracklist(modules.Module):
             self.list.setItem(self.list.getMark(), ROW_ICO, icon)
 
 
+    def onTracklistPlay(self, idx, seconds):
+        """ Play the given track """
+        self.jumpTo(idx)
+
+        if seconds != 0:
+            modules.postMsg(consts.MSG_CMD_SEEK, {'seconds': seconds})
+
+
+    def onTracklistPlayPause(self, idx, seconds):
+        """ Play the given track but pause immediately """
+        self.onTracklistPlay(idx, seconds)
+        modules.postMsg(consts.MSG_CMD_TOGGLE_PAUSE)
+
+
     # --== GTK handlers ==--
 
 
@@ -512,6 +554,7 @@ class Tracklist(modules.Module):
         elif colTitle == _('Genre'):    colId = COL_GENRE
         elif colTitle == _('Date'):     colId = COL_DATE
         elif colTitle == _('Bit Rate'): colId = COL_BITRATE
+        elif colTitle == _('File'):     colId = COL_FILENAME
         else:                           colId = COL_PATH
 
         visibility = tools.prefs.get(__name__, 'columns-visibility-2', PREFS_DEFAULT_COLUMNS_VISIBILITY)
